# Copyright (C) 2010-2023 Bastian Kleineidam
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Test the arj program"""

from . import ArchiveTest
from .. import needs_program


class TestArj(ArchiveTest):
    """Test class for the arj program"""

    program = 'arj'

    @needs_program(program)
    def test_arj(self):
        """Run archive commands with ARJ archive."""
        self.archive_commands(self.filename + '.arj')

    @needs_program('file')
    @needs_program(program)
    def test_arj_file(self):
        """Run archive commands with renamed ARJ archive."""
        self.archive_commands(self.filename + '.arj.foo', skip_create=True)


class TestArjPassword(TestArj):
    """Test class for the arj program with password protected archives"""

    password = 'thereisnotry'
    filename = 'p'
